package com.academiaandroid.conexionwifi;

//Ejemplo aplicacin Android que obtiene los datos relacionados de la conexin Inalmbrica
//con el dispositivo Android
//academiaandroid.com
//
//by Jos Antonio Gzquez Rodrguez


import android.content.Context;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v7.app.ActionBarActivity;
import android.text.format.Formatter;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends ActionBarActivity {

	//Declaramos los componentes necesarios para mostrar la informacin de la conexin de red
	private TextView estadoTV;
	private TextView pingTV;
	private TextView ipTV;
	private TextView velocidadTV;
	private TextView conexionInalambricaTV;
	//Clase que nos proporcionada la gestin de todos los aspectos de una conexin Wifi
	private WifiManager wifi;
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        if (savedInstanceState == null) {
            getSupportFragmentManager().beginTransaction()
                    .add(R.id.container, new PlaceholderFragment())
                    .commit();
        }
        
        //Enlazamos los componentes con los recursos definidos a nivel de layout.
        estadoTV = (TextView)findViewById(R.id.txtEstado);
        pingTV = (TextView)findViewById(R.id.txtPing);
        ipTV = (TextView)findViewById(R.id.txtIP);
        velocidadTV = (TextView)findViewById(R.id.txtVelocidad);
        conexionInalambricaTV = (TextView)findViewById(R.id.txtNombre);
        wifi = (WifiManager)getSystemService(Context.WIFI_SERVICE);  
    }
    
    //Evento On Click que reiniciar los valores de cada componente TextView definido.
    public void reiniciarValores(View view)
    {
    	try
    	{
    		estadoTV.setTextColor(0xFF000000);
	    	estadoTV.setText("Sin Estado");
	    	pingTV.setTextColor(0xFF000000);
	    	pingTV.setText("Sin Ping");
	    	ipTV.setTextColor(0xFF000000);
	    	ipTV.setText("Sin IP");
	    	velocidadTV.setTextColor(0xFF000000);
	    	velocidadTV.setText("Sin Velocidad");
	    	conexionInalambricaTV.setTextColor(0xFF000000);
	    	conexionInalambricaTV.setText("Sin Nombre");
    	}catch(Exception ex)
    	{
    		ex.getMessage();
    	}   	
    }
    
    //Evento On Click que muestra si hay una conexin establecida mediante WIFI
    public void mostrarEstado(View view)
    {   
    	try
    	{
    		
	    	//Mtodo que devuelve un valor de verdadero o falso si se ha establecido la conexin Wifi.
	    	boolean estadoWifi = wifi.isWifiEnabled();
	    	String estado_conexion;
	    	if(estadoWifi == true)
	    	{
	    		estadoTV.setTextColor(0xFF0000FF);
	    		estado_conexion = "Conectado!!!";
	    		estadoTV.setText(estado_conexion);
	    		Toast.makeText(this, "Estado Conexin: " + estado_conexion, Toast.LENGTH_LONG).show();
	    	}else
	    	{
	    		estadoTV.setTextColor(0xFF0000FF);
	    		estado_conexion = "Desconectado!!!";
	    		estadoTV.setText(estado_conexion);
	    		Toast.makeText(this, "Estado Conexin: " + estado_conexion, Toast.LENGTH_LONG).show();
	    	}
    	}catch(Exception ex)
    	{
    		ex.getMessage();
    	}
    }
    
    //Evento On Click que comprueba si el dispositivo responde con la IP Local establecida
    public void hacerPing(View view)
    {
    	try
    	{	
    		//Mtodo que devuelve un valor de verdadero o falso si responde a la IP Local asignada.
	    	boolean ip_ping = wifi.pingSupplicant();
	    	if(ip_ping == true)
	    	{
	    		pingTV.setTextColor(0xFF0000FF);
	    		pingTV.setText("IP con conectividad TCP/IP");
	    		Toast.makeText(this, "IP con conectividad TCP/IP", Toast.LENGTH_LONG).show();
	    	}
	    	else
	    	{
	    		pingTV.setTextColor(0xFF0000FF);
	    		pingTV.setText("IP sin conectividad TCP/IP");
	    		Toast.makeText(this, "IP sin conectividad TCP/IP", Toast.LENGTH_LONG).show();
	    	}
	    }catch(Exception ex)
		{
			ex.getMessage();
		}
    }
    
    //Evento On Click que muestra la IP Local asignada al dispositivo Android.
    public void mostrarIP(View view)
    {   	   	
		try 
		{									    	
	    	@SuppressWarnings("deprecation")
	    	//Mtodo que devuelve el valor de la IP Local asignada al dispositivo. No soporta IPv6
			String ip_local =  Formatter.formatIpAddress(wifi.getConnectionInfo().getIpAddress());
	    	ipTV.setTextColor(0xFF0000FF);
	    	ipTV.setText(ip_local);
	    	Toast.makeText(this, "IP Local: " + ip_local, Toast.LENGTH_LONG).show();
	    	
		}catch (Exception e) 
		{			
			e.printStackTrace();
		}  	
    }
    
    //Evento On Click que muestra la velocidad de transmisin de datos entre el router y el dispositivo Android
    public void mostrarVelocidad(View view)
    {
		try
		{ 
			//Mtodo que devuelve el valor de la conexin Wifi, si est activa (si no est activa muestra -1Mbps)
	    	WifiInfo info = wifi.getConnectionInfo();
			String puertoDatos = String .valueOf(info.getLinkSpeed());
			velocidadTV.setTextColor(0xFF0000FF);
			velocidadTV.setText(puertoDatos + "Mbps");
			Toast.makeText(this, "Velocidad de Red: " + puertoDatos + "Mbps", Toast.LENGTH_LONG).show();
						
		} catch (Exception e) 
		{			
			e.getMessage();
		}   	
    }
    
    //Evento On CLick encargado de mostrar el identificador de la red Wifi a la que se ha conectado.
    public void mostrarNombreConexion(View view)
    {
    	try
    	{
	    	//Mtodo que devuelve el identificador de servicio de la red Wifi 802.11
	    	String red = wifi.getConnectionInfo().getSSID();	    	
	    	if(red == null)
	    	{
	    		conexionInalambricaTV.setTextColor(0xFF0000FF);
				conexionInalambricaTV.setText("Sin Red");
				Toast.makeText(this, "Prueba de red: " + red, Toast.LENGTH_LONG).show();
	    	}else
	    	{
		    	conexionInalambricaTV.setTextColor(0xFF0000FF);
				conexionInalambricaTV.setText(red);
				Toast.makeText(this, "Prueba de red: " + red, Toast.LENGTH_LONG).show();
	    	}
	    }catch (Exception e) 
		{			
			e.getMessage();
		}  	
    }
   
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        int id = item.getItemId();
        if (id == R.id.action_settings) {
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    /**
     * A placeholder fragment containing a simple view.
     */
    public static class PlaceholderFragment extends Fragment {

        public PlaceholderFragment() {
        }

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,
                Bundle savedInstanceState) {
            View rootView = inflater.inflate(R.layout.fragment_main, container, false);
            return rootView;
        }
    }

}
